@@ -5,14 +5,17 @@ from mathpad.units import *
 
 from mathpad.solve import solve, Solution
 from mathpad.equation import Equation
-from mathpad._quality_of_life import t, g, pi, frac
+from mathpad._quality_of_life import t, pi, i, e, dimensionless, mathpad_constructor
 from mathpad.algebra import subs, simplify, factor, expand
 
 from mathpad.functions import piecewise, sqrt
 from mathpad.calculus import diff, integral
 from mathpad.trigonometry import cos, sin, tan
 from mathpad.vector_space import VectorSpace, R2, R3
+from mathpad.vector import Vector
+from mathpad.matrix import Matrix
 from mathpad.simulate_dynamic_system import simulate_dynamic_system
+from mathpad.codegen import as_numpy_func
 
 try:
     from IPython.display import display
@@ -23,4 +26,4 @@ except ImportError:
 sympy.init_printing()  # type: ignore
 sympy.printing.printer.Printer.set_global_settings(min=-3, max=4)  # type: ignore
 
-__version__ = "0.2.2"
+__version__ = "1.0.0"
